Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorWillian Padovani Germano <wpgermano@gmail.com>2003-06-24 11:21:17 +0400
committerWillian Padovani Germano <wpgermano@gmail.com>2003-06-24 11:21:17 +0400
commit06ee04fb05ff58e6e0a781b64100825ba7358f19 (patch)
treec90b1415ebb106090c6f94b4ee782146245bc67d /source/blender/python/api2_2x/rgbTuple.h
parenta0ea4df1ba0367657ba4e093ca0d1288d6258ba4 (diff)
* Added more doc files for epydoc and a test for the camera module.
* Moved public declarations in camera and lamp to a new file: bpy_types.h. * Fixed minor bugs in material, rgbTuple and Lamp + other minor changes. * Made part of the changes to conform to decided naming conventions.
Diffstat (limited to 'source/blender/python/api2_2x/rgbTuple.h')
-rw-r--r--source/blender/python/api2_2x/rgbTuple.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/python/api2_2x/rgbTuple.h b/source/blender/python/api2_2x/rgbTuple.h
index a2ca43d3ae8..731c8904738 100644
--- a/source/blender/python/api2_2x/rgbTuple.h
+++ b/source/blender/python/api2_2x/rgbTuple.h
@@ -41,19 +41,19 @@
* objects, so this header file must contain only 'public' declarations */
/*****************************************************************************/
/* Python C_rgbTuple structure definition: */
/*****************************************************************************/
typedef struct {
PyObject_HEAD
float *rgb[3]; /* array of three pointers to floats */
-} C_rgbTuple;
+} BPy_rgbTuple;
/*****************************************************************************/
/* Python API function prototypes for the rgbTuple helper module. */
/*****************************************************************************/
PyObject *rgbTuple_New (float *rgb[3]);
-PyObject *rgbTuple_getCol (C_rgbTuple *self);
-PyObject *rgbTuple_setCol (C_rgbTuple *self, PyObject *args);
+PyObject *rgbTuple_getCol (BPy_rgbTuple *self);
+PyObject *rgbTuple_setCol (BPy_rgbTuple *self, PyObject *args);
#endif /* EXPP_rgbTuple_H */
@@ -41,19 +41,19 @@
* objects, so this header file must contain only 'public' declarations */
/*****************************************************************************/
-/* Python C_rgbTuple structure definition: */
+/* Python BPy_rgbTuple structure definition: */
/*****************************************************************************/
typedef struct {